==> ametys-plugin-odf-4.8.16.20251030-0036-b331-SNAPSHOT.jar: org/ametys/plugins/odf/resources/js/Ametys/plugins/odf/content/controller/TranslateMenu.js <==
/*
 *  Copyright 2015 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

/**
 * Language menu button for the list of languages in the skin
 */
Ext.define('Ametys.plugins.odf.content.controller.TranslateMenu', {
    extend: 'Ametys.ribbon.element.ui.ButtonController',
    
    createUI: function(size, colspan)
    {
        var element = this.callParent(arguments);
        element.on("menushow", this._onMenuShow, this);
        return element;
    },
    
    /**
     * Listener for the "menushow" event. 
     * Disable the current language
     * @param {Ext.button.Button} button The button that launched the event.
     * @param {Ext.menu.Menu} menu The menu that is displayed.
     * @private
     */
    _onMenuShow: function (button, menu)
    {
        var targets = this.getMatchingTargets();
        if (targets.length > 0)
        {
            var currentLanguage = targets[0].getParameters().lang;
            
            this._getGalleries(button).each(function (gallery) {
                gallery.items.each(function (item) {
                    var controller = Ametys.ribbon.RibbonManager.getUI(item.controlId);
                    var lang = controller.getInitialConfig("code");
                    item.setDisabled(currentLanguage == lang);
                });
            });
        }
    }
    
});

==> ametys-plugin-odf-4.9.7.20260218-0020-b155-SNAPSHOT.jar: org/ametys/plugins/odf/resources/js/Ametys/plugins/odf/content/controller/TranslateMenu.js <==
/*
 *  Copyright 2015 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

/**
 * Language menu button for the list of languages in the skin
 */
Ext.define('Ametys.plugins.odf.content.controller.TranslateMenu', {
    extend: 'Ametys.plugins.cms.content.controller.SmartContentController',
    
    createUI: function(size, colspan)
    {
        var element = this.callParent(arguments);
        element.on("menushow", this._onMenuShow, this);
        return element;
    },
    
    /**
     * Listener for the "menushow" event. 
     * Disable the current language
     * @param {Ext.button.Button} button The button that launched the event.
     * @param {Ext.menu.Menu} menu The menu that is displayed.
     * @private
     */
    _onMenuShow: function (button, menu)
    {
        var targets = this.getMatchingTargets();
        if (targets.length > 0)
        {
            var currentLanguage = targets[0].getParameters().lang;
            
            this._getGalleries(button).each(function (gallery) {
                gallery.items.each(function (item) {
                    var controller = Ametys.ribbon.RibbonManager.getUI(item.controlId);
                    var lang = controller.getInitialConfig("code");
                    item.setDisabled(currentLanguage == lang);
                });
            });
        }
    }
    
});
